Morlet

Struct Morlet 

pub struct Morlet { /* private fields */ }
Morlet Wavelet

The Morlet wavelet is a complex exponential multiplied by a Gaussian window. It provides excellent time-frequency localization.

ψ(t) = π^(-1/4) * exp(iω₀t) * exp(-t²/2)

Implementations



impl Morlet

pub fn new(omega0: f64) -> Self

Create a new Morlet wavelet with given central frequency

pub fn with_default_omega() -> Self

Create Morlet wavelet with default ω₀ = 6.0